item-icon-size=2
category-icon-size=1
hover-switch-category=true
launcher-show-description=false
button-icon=kali-panel-menu
position-search-alternate=false
position-categories-alternate=true
position-profile-alternate=true
load-hierarchy=true
menu-width=570
menu-height=700
show-command-profile=false
favorites=exo-terminal-emulator.desktop,root-terminal.desktop,exo-file-manager.desktop,xfce-text-editor.desktop,exo-web-browser.desktop,kali-www.desktop,kali-tools.desktop,kali-docs.desktop,kali-bugs.desktop,offsec-training.desktop,exploit-database.desktop,vulnhub.desktop
command-settings=xfce4-settings-manager
show-command-settings=true
show-command-lockscreen=false
show-command-switchuser=false
show-command-logoutuser=false
show-command-restart=false
show-command-shutdown=false
show-command-suspend=false
show-command-hibernate=false
show-command-logout=true
show-command-menueditor=false
show-command-profile=false
